==> haskell-miniutter-0.5.1.2-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-miniutter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 miniutter
version:              0.5.1.2
visibility:           public
id:                   miniutter-0.5.1.2-Gr6jgGNnNuxLgrCqnKbmqI
key:                  miniutter-0.5.1.2-Gr6jgGNnNuxLgrCqnKbmqI
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Mikolaj Konarski
homepage:             https://github.com/Mikolaj/miniutter
synopsis:             Simple English clause creation from arbitrary words
description:
    This library helps in generating simple present tense
    English sentences from short, parametrized descriptions.
    In a typical use, the structure of a clause is fixed,
    but the particular words to be used vary in arbitrary ways.
    The main goal of the library is to minimize the API
    complexity and the code size of programs that use it.
    The library doesn'\''t attempt to ban incorrect English sentences,
    but just make the creation of the simple correct ones easy
    and predictable.

category:             Natural Language Processing
abi:                  1c3420e3c0735bf648506555c9a4afd2
exposed:              True
exposed-modules:      NLP.Miniutter.English
import-dirs:          /usr/lib/ghc-9.0.2/site-local/miniutter-0.5.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/miniutter-0.5.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-miniutter
hs-libraries:         HSminiutter-0.5.1.2-Gr6jgGNnNuxLgrCqnKbmqI
depends:
    base-4.15.1.0 binary-0.8.8.0 containers-0.6.4.1
    minimorph-0.3.0.1-HG9XpAUY1SMBTXzjMSA4II text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-miniutter/html/miniutter.haddock
haddock-html:         /usr/share/doc/haskell-miniutter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-miniutter-0.5.1.2-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-miniutter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 miniutter
version:              0.5.1.2
visibility:           public
id:                   miniutter-0.5.1.2-LogdVf9VMEeAVTUBYUDU23
key:                  miniutter-0.5.1.2-LogdVf9VMEeAVTUBYUDU23
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Mikolaj Konarski
homepage:             https://github.com/Mikolaj/miniutter
synopsis:             Simple English clause creation from arbitrary words
description:
    This library helps in generating simple present tense
    English sentences from short, parametrized descriptions.
    In a typical use, the structure of a clause is fixed,
    but the particular words to be used vary in arbitrary ways.
    The main goal of the library is to minimize the API
    complexity and the code size of programs that use it.
    The library doesn'\''t attempt to ban incorrect English sentences,
    but just make the creation of the simple correct ones easy
    and predictable.

category:             Natural Language Processing
abi:                  d7b5e584af7fb0a3fefd7e931557e2dc
exposed:              True
exposed-modules:      NLP.Miniutter.English
import-dirs:          /usr/lib/ghc-9.0.2/site-local/miniutter-0.5.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/miniutter-0.5.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-miniutter
hs-libraries:         HSminiutter-0.5.1.2-LogdVf9VMEeAVTUBYUDU23
depends:
    base-4.15.1.0 binary-0.8.8.0 containers-0.6.4.1
    minimorph-0.3.0.1-Dr3WRd5sYdzIXsc4ANuJTi text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-miniutter/html/miniutter.haddock
haddock-html:         /usr/share/doc/haskell-miniutter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
